@@ -3,11 +3,13 @@ mod mock_locator;
 mod mocks;
 mod mry;
 mod rule;
+mod static_mocks;
 
 pub use crate::mry::*;
 use mock::*;
 pub use mock_locator::*;
 pub use mocks::*;
-pub use mry_macros::*;
+pub use mry_macros::{mry, new, lock, m};
 pub use rule::*;
+pub use static_mocks::*;
 pub use Matcher::Any;
